==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/APIServerNamedServingCertFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class APIServerNamedServingCertFluentImpl<A extends APIServerNamedServingCertFluent<A>> extends BaseFluent<A> implements APIServerNamedServingCertFluent<A>{
  public APIServerNamedServingCertFluentImpl() {
  }
  public APIServerNamedServingCertFluentImpl(APIServerNamedServingCert instance) {
    this.withNames(instance.getNames()); 
    this.withServingCertificate(instance.getServingCertificate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private List<String> names = new ArrayList<String>();
  private SecretNameReferenceBuilder servingCertificate;
  private Map<String,Object> additionalProperties;
  public A addToNames(Integer index,String item) {
    if (this.names == null) {this.names = new ArrayList<String>();}
    this.names.add(index, item);
    return (A)this;
  }
  public A setToNames(Integer index,String item) {
    if (this.names == null) {this.names = new ArrayList<String>();}
    this.names.set(index, item); return (A)this;
  }
  public A addToNames(java.lang.String... items) {
    if (this.names == null) {this.names = new ArrayList<String>();}
    for (String item : items) {this.names.add(item);} return (A)this;
  }
  public A addAllToNames(Collection<String> items) {
    if (this.names == null) {this.names = new ArrayList<String>();}
    for (String item : items) {this.names.add(item);} return (A)this;
  }
  public A removeFromNames(java.lang.String... items) {
    for (String item : items) {if (this.names!= null){ this.names.remove(item);}} return (A)this;
  }
  public A removeAllFromNames(Collection<String> items) {
    for (String item : items) {if (this.names!= null){ this.names.remove(item);}} return (A)this;
  }
  public List<String> getNames() {
    return this.names;
  }
  public String getName(Integer index) {
    return this.names.get(index);
  }
  public String getFirstName() {
    return this.names.get(0);
  }
  public String getLastName() {
    return this.names.get(names.size() - 1);
  }
  public String getMatchingName(Predicate<String> predicate) {
    for (String item: names) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingName(Predicate<String> predicate) {
    for (String item: names) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNames(List<String> names) {
    if (names != null) {this.names = new ArrayList(); for (String item : names){this.addToNames(item);}} else { this.names = null;} return (A) this;
  }
  public A withNames(java.lang.String... names) {
    if (this.names != null) {this.names.clear();}
    if (names != null) {for (String item :names){ this.addToNames(item);}} return (A) this;
  }
  public Boolean hasNames() {
    return names != null && !names.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildServingCertificate instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getServingCertificate() {
    return this.servingCertificate!=null ?this.servingCertificate.build():null;
  }
  public SecretNameReference buildServingCertificate() {
    return this.servingCertificate!=null ?this.servingCertificate.build():null;
  }
  public A withServingCertificate(SecretNameReference servingCertificate) {
    _visitables.get("servingCertificate").remove(this.servingCertificate);
    if (servingCertificate!=null){ this.servingCertificate= new SecretNameReferenceBuilder(servingCertificate); _visitables.get("servingCertificate").add(this.servingCertificate);} else { this.servingCertificate = null; _visitables.get("servingCertificate").remove(this.servingCertificate); } return (A) this;
  }
  public Boolean hasServingCertificate() {
    return this.servingCertificate != null;
  }
  public A withNewServingCertificate(String name) {
    return (A)withServingCertificate(new SecretNameReference(name));
  }
  public APIServerNamedServingCertFluent.ServingCertificateNested<A> withNewServingCertificate() {
    return new APIServerNamedServingCertFluentImpl.ServingCertificateNestedImpl();
  }
  public APIServerNamedServingCertFluent.ServingCertificateNested<A> withNewServingCertificateLike(SecretNameReference item) {
    return new APIServerNamedServingCertFluentImpl.ServingCertificateNestedImpl(item);
  }
  public APIServerNamedServingCertFluent.ServingCertificateNested<A> editServingCertificate() {
    return withNewServingCertificateLike(getServingCertificate());
  }
  public APIServerNamedServingCertFluent.ServingCertificateNested<A> editOrNewServingCertificate() {
    return withNewServingCertificateLike(getServingCertificate() != null ? getServingCertificate(): new SecretNameReferenceBuilder().build());
  }
  public APIServerNamedServingCertFluent.ServingCertificateNested<A> editOrNewServingCertificateLike(SecretNameReference item) {
    return withNewServingCertificateLike(getServingCertificate() != null ? getServingCertificate(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    APIServerNamedServingCertFluentImpl that = (APIServerNamedServingCertFluentImpl) o;
    if (names != null ? !names.equals(that.names) :that.names != null) return false;
    if (servingCertificate != null ? !servingCertificate.equals(that.servingCertificate) :that.servingCertificate != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(names,  servingCertificate,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (names != null && !names.isEmpty()) { sb.append("names:"); sb.append(names + ","); }
    if (servingCertificate != null) { sb.append("servingCertificate:"); sb.append(servingCertificate + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ServingCertificateNestedImpl<N> extends SecretNameReferenceFluentImpl<APIServerNamedServingCertFluent.ServingCertificateNested<N>> implements APIServerNamedServingCertFluent.ServingCertificateNested<N>,Nested<N>{
    ServingCertificateNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    ServingCertificateNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) APIServerNamedServingCertFluentImpl.this.withServingCertificate(builder.build());
    }
    public N endServingCertificate() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/APIServerNamedServingCertFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class APIServerNamedServingCertFluentImpl<A extends APIServerNamedServingCertFluent<A>> extends BaseFluent<A> implements APIServerNamedServingCertFluent<A>{
  public APIServerNamedServingCertFluentImpl() {
  }
  public APIServerNamedServingCertFluentImpl(APIServerNamedServingCert instance) {
    if (instance != null) {
      this.withNames(instance.getNames());
      this.withServingCertificate(instance.getServingCertificate());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private List<String> names = new ArrayList<String>();
  private SecretNameReferenceBuilder servingCertificate;
  private Map<String,Object> additionalProperties;
  public A addToNames(int index,String item) {
    if (this.names == null) {this.names = new ArrayList<String>();}
    this.names.add(index, item);
    return (A)this;
  }
  public A setToNames(int index,String item) {
    if (this.names == null) {this.names = new ArrayList<String>();}
    this.names.set(index, item); return (A)this;
  }
  public A addToNames(java.lang.String... items) {
    if (this.names == null) {this.names = new ArrayList<String>();}
    for (String item : items) {this.names.add(item);} return (A)this;
  }
  public A addAllToNames(Collection<String> items) {
    if (this.names == null) {this.names = new ArrayList<String>();}
    for (String item : items) {this.names.add(item);} return (A)this;
  }
  public A removeFromNames(java.lang.String... items) {
    for (String item : items) {if (this.names!= null){ this.names.remove(item);}} return (A)this;
  }
  public A removeAllFromNames(Collection<String> items) {
    for (String item : items) {if (this.names!= null){ this.names.remove(item);}} return (A)this;
  }
  public List<String> getNames() {
    return this.names;
  }
  public String getName(int index) {
    return this.names.get(index);
  }
  public String getFirstName() {
    return this.names.get(0);
  }
  public String getLastName() {
    return this.names.get(names.size() - 1);
  }
  public String getMatchingName(Predicate<String> predicate) {
    for (String item: names) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingName(Predicate<String> predicate) {
    for (String item: names) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNames(List<String> names) {
    if (names != null) {this.names = new ArrayList(); for (String item : names){this.addToNames(item);}} else { this.names = null;} return (A) this;
  }
  public A withNames(java.lang.String... names) {
    if (this.names != null) {this.names.clear(); _visitables.remove("names"); }
    if (names != null) {for (String item :names){ this.addToNames(item);}} return (A) this;
  }
  public Boolean hasNames() {
    return names != null && !names.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildServingCertificate instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getServingCertificate() {
    return this.servingCertificate!=null ?this.servingCertificate.build():null;
  }
  public SecretNameReference buildServingCertificate() {
    return this.servingCertificate!=null ?this.servingCertificate.build():null;
  }
  public A withServingCertificate(SecretNameReference servingCertificate) {
    _visitables.get("servingCertificate").remove(this.servingCertificate);
    if (servingCertificate!=null){ this.servingCertificate= new SecretNameReferenceBuilder(servingCertificate); _visitables.get("servingCertificate").add(this.servingCertificate);} else { this.servingCertificate = null; _visitables.get("servingCertificate").remove(this.servingCertificate); } return (A) this;
  }
  public Boolean hasServingCertificate() {
    return this.servingCertificate != null;
  }
  public A withNewServingCertificate(String name) {
    return (A)withServingCertificate(new SecretNameReference(name));
  }
  public APIServerNamedServingCertFluentImpl.ServingCertificateNested<A> withNewServingCertificate() {
    return new APIServerNamedServingCertFluentImpl.ServingCertificateNestedImpl();
  }
  public APIServerNamedServingCertFluentImpl.ServingCertificateNested<A> withNewServingCertificateLike(SecretNameReference item) {
    return new APIServerNamedServingCertFluentImpl.ServingCertificateNestedImpl(item);
  }
  public APIServerNamedServingCertFluentImpl.ServingCertificateNested<A> editServingCertificate() {
    return withNewServingCertificateLike(getServingCertificate());
  }
  public APIServerNamedServingCertFluentImpl.ServingCertificateNested<A> editOrNewServingCertificate() {
    return withNewServingCertificateLike(getServingCertificate() != null ? getServingCertificate(): new SecretNameReferenceBuilder().build());
  }
  public APIServerNamedServingCertFluentImpl.ServingCertificateNested<A> editOrNewServingCertificateLike(SecretNameReference item) {
    return withNewServingCertificateLike(getServingCertificate() != null ? getServingCertificate(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    APIServerNamedServingCertFluentImpl that = (APIServerNamedServingCertFluentImpl) o;
    if (!java.util.Objects.equals(names, that.names)) return false;

    if (!java.util.Objects.equals(servingCertificate, that.servingCertificate)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(names,  servingCertificate,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (names != null && !names.isEmpty()) { sb.append("names:"); sb.append(names + ","); }
    if (servingCertificate != null) { sb.append("servingCertificate:"); sb.append(servingCertificate + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ServingCertificateNestedImpl<N> extends SecretNameReferenceFluentImpl<APIServerNamedServingCertFluentImpl.ServingCertificateNested<N>> implements APIServerNamedServingCertFluentImpl.ServingCertificateNested<N>,Nested<N>{
    ServingCertificateNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    ServingCertificateNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) APIServerNamedServingCertFluentImpl.this.withServingCertificate(builder.build());
    }
    public N endServingCertificate() {
      return and();
    }
    
  }
  
}
